@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Async::Util;
-$Search::Elasticsearch::Async::Util::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::Async::Util::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Async::Util::VERSION = '6.8001';use Moo;
 use Scalar::Util qw(blessed);
 use Sub::Exporter -setup => { exports => ['thenable'] };
 
@@ -29,15 +30,15 @@ Search::Elasticsearch::Async::Util - A utility class for internal use by Elastic
 
 =head1 VERSION
 
-version 6.00
+version 6.80_01
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
