@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Cxn::AEHTTP;
-$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '6.00';
-use AnyEvent::HTTP qw(http_request);
+$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Cxn::AEHTTP::VERSION = '6.8001';use AnyEvent::HTTP qw(http_request);
 use Promises qw(deferred);
 use Try::Tiny;
 use Moo;
@@ -95,7 +96,7 @@ Search::Elasticsearch::Cxn::AEHTTP - An async Cxn implementation which uses AnyE
 
 =head1 VERSION
 
-version 6.00
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -273,11 +274,11 @@ From L<Search::Elasticsearch::Role::Async::Cxn>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
