@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Cxn::Mojo;
-$Search::Elasticsearch::Cxn::Mojo::VERSION = '6.00';
-use Mojo::UserAgent();
+$Search::Elasticsearch::Cxn::Mojo::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::Cxn::Mojo::VERSION = '6.8001';use Mojo::UserAgent();
 use Promises qw(deferred);
 use Try::Tiny;
 use Moo;
@@ -106,7 +107,7 @@ Search::Elasticsearch::Cxn::Mojo - An async Cxn implementation which uses Mojo::
 
 =head1 VERSION
 
-version 6.00
+version 6.80_01
 
 =head1 DESCRIPTION
 
@@ -288,11 +289,11 @@ From L<Search::Elasticsearch::Role::Async::Cxn>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
