@@ -1,6 +1,7 @@
 package Search::Elasticsearch::CxnPool::Async::Static::NoPing;
-$Search::Elasticsearch::CxnPool::Async::Static::NoPing::VERSION = '6.00';
-use Moo;
+$Search::Elasticsearch::CxnPool::Async::Static::NoPing::VERSION = '6.80_01'; # TRIAL
+
+$Search::Elasticsearch::CxnPool::Async::Static::NoPing::VERSION = '6.8001';use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Static::NoPing',
     'Search::Elasticsearch::Role::Is_Async';
 
@@ -42,7 +43,7 @@ Search::Elasticsearch::CxnPool::Async::Static::NoPing - An async CxnPool for con
 
 =head1 VERSION
 
-version 6.00
+version 6.80_01
 
 =head1 SYNOPSIS
 
@@ -185,11 +186,11 @@ From L<Search::Elasticsearch::Role::CxnPool>
 
 =head1 AUTHOR
 
-Clinton Gormley <drtech@cpan.org>
+Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
